"""Development-time infrastructure for pyrig projects.

This package contains development tools, configuration management, CLI,
artifact building, and testing infrastructure. These components are used
during development and CI/CD but are not required at runtime.
"""
